#proto.spec -> base.spec -> mesa.spec -> server.spec

%define ALD_Ver		1.2.4

Name:         X11-proto
Version:      7.7
Release:      4

License:      The Xorg Project
Summary:      Development Basic X11 package
Group:        Development/Libraries

Source:  X11R%{version}.%{release}.proto.tar
Source1: CROSS-X11.sh

%define DestDir		/X11/%{version}-%{release}
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%define _prefix /usr/X11R%{version}
%define _libdir	%{_prefix}/%{_lib}
%define protoPrefix /var/tmp/X11R%{version}-%{release}/%{TO_ARCH}
%define protoDir %{protoPrefix}%{_prefix}

%define _defaultdocdir	%{_prefix}/share/doc
%define _mandir %{_prefix}/man

%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin
%define target_  %{target}-
%define hosttarget --host=%{target}

%define cross_prefix	%{csysdir}%{_prefix}
%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysdir		%{nil}
%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_build}
%define target_  %{nil}
%define hosttarget %{nil}

%endif # !_CROSS

%define __os_install_post %{nil}

%define docdir %{_defaultdocdir}/%{name}
%define xlibDir  %{protoPrefix}%{_libdir}

# ------------------- description ------------------------------------
%description
Development Basic X11 package
#-------------------------------
%package xcb-python
Summary: Python bindings for %{name}
Group: Development/Libraries
%description xcb-python
The %{name}-python package
#-------------------------------
%package doc
Summary:      doc for %{name}
Group:        Documentation
%description doc
doc for %{name}
#-------------------------------
%package doc-devel
Summary:      Doc build data for X11
Group:        Development/Libraries
%description doc-devel
Doc build data for X11

#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries
# --------------------------------------
%package %{TO_ARCH}-doc
Summary:      %{name} Cross-%{TO_ARCH} doc
Group:        Development/Libraries
%description %{TO_ARCH}-doc
%{name} Cross-%{TO_ARCH} doc

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n X11R%{version}.%{release}.proto

if test ! -f %{protoPrefix}%{_datadir}/sgml/X11/dbs/masterdb.html.xml -a -f %{_datadir}/sgml/X11/dbs/masterdb.html.xml; then
mkdir -p %{protoPrefix}%{_datadir}
cp -ar %{_datadir}/sgml %{protoPrefix}%{_datadir}/
sed -i s:"%{_datadir}":"%{protoPrefix}%{_datadir}": %{protoPrefix}%{_datadir}/sgml/X11/dbs/masterdb.html.xml
sed -i s:"%{_datadir}":"%{protoPrefix}%{_datadir}": %{protoPrefix}%{_datadir}/sgml/X11/dbs/masterdb.pdf.xml
fi
if test ! -f %{protoPrefix}/usr/share/pkgconfig/xorg-sgml-doctools.pc -a -f /usr/share/pkgconfig/xorg-sgml-doctools.pc; then
cp /usr/share/pkgconfig/xorg-sgml-doctools.pc %{protoPrefix}/usr/share/pkgconfig/
sed -i s:"\${prefix}/share":"%{protoPrefix}%{_datadir}": %{protoPrefix}/usr/share/pkgconfig/xorg-sgml-doctools.pc
fi

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

case `python -V 2>&1` in
  'Python 2.6.'*) TARGET_PYTHONDIR=/python2.6/site-packages ;;
  'Python 2.7.'*) TARGET_PYTHONDIR=/python2.7/site-packages ;;
  'Python 3.4.'*) TARGET_PYTHONDIR=/python3.4/site-packages ;;
  'Python 3.5.'*) TARGET_PYTHONDIR=/python3.5/site-packages ;;
  'Python 3.6.'*) TARGET_PYTHONDIR=/python3.6/site-packages ;;
  *) 
    echo "ERROR: no python"
    exit 1
  ;;
esac

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections"
LDFLAGS="-Wl,--gc-sections"


TARGET_PRFIX=%{_prefix}
RPM_TMP_ROOT=$RPM_BUILD_ROOT/tmp
TARGET_INSTDIR=$RPM_BUILD_ROOT%{csysdir}%{_prefix}
TARGET_NAME=%{target_}
TARGET_LIB=%{_lib}
export TARGET_PRFIX RPM_TMP_ROOT TARGET_INSTDIR TARGET_PYTHONDIR TARGET_NAME TARGET_LIB

TARGET_ProtoDir=%{protoDir}
TARGET_CrossDir=%{csysdir}%{_prefix}
MKCROSSDIR=%{BUILD_LOCAL_CROSS}
export TARGET_ProtoDir TARGET_CrossDir MKCROSSDIR


rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_TMP_ROOT
mkdir -p %{protoDir}

export PKG_CONFIG_PATH="%{xlibDir}/pkgconfig"

prefproto="--build=%{_build} %{hosttarget} \
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--libexecdir=%{_libdir} \
	--datarootdir=%{_libdir} \
	--mandir=%{_prefix}/man \
	--localstatedir=/var \
	--sysconfdir=/etc"

%if 0
for sf in util-macros-1.17; do

  tar -xaf $sf.tar.xz
  cd $sf
    ./configure $prefproto --docdir=%{_defaultdocdir}/$sf &>Fconfigure_log.txt
    make DESTDIR=$RPM_TMP_ROOT install &>FInstall_log.txt
    %SOURCE1 $sf
  cd ..
done

%else

for sf in util-macros-1.17 xproto-7.0.26 xextproto-7.3.0 xcmiscproto-1.2.2 \
	bigreqsproto-1.1.2 kbproto-1.0.6 inputproto-2.3.1 randrproto-1.4.0 \
	renderproto-0.11.1 fixesproto-5.0 damageproto-1.2.1 \
	xf86vidmodeproto-2.3.1 fontsproto-2.1.2 xf86bigfontproto-1.2.0  \
	compositeproto-0.4.2 scrnsaverproto-1.2.2 resourceproto-1.2.0 \
	xineramaproto-1.2.1 xf86dgaproto-2.1 recordproto-1.14.2 \
	glproto-1.4.17 xf86driproto-2.1.1 videoproto-2.3.2 dri2proto-2.8 \
	dri3proto-1.0 presentproto-1.0 xcb-proto-1.10; do

  tar -xaf $sf.tar.xz
  cd $sf
    xf=`echo $sf | cut -d '-' -f 1`
    ./configure $prefproto --docdir=%{_defaultdocdir}/$xf &>Fconfigure_log.txt
    make DESTDIR=$RPM_TMP_ROOT install &>FInstall_log.txt
    %SOURCE1 $sf
  cd ..
done
%endif

# ------------------- Install ----------------------------------------
%Install

%Clean 
DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-xcb-python-$SE $DD/%{name}-xcb-python-$DE
  mv %{name}-doc-$SE $DD/%{name}-doc-$DE
  mv %{name}-doc-devel-$SE $DD/%{name}-doc-devel-$DE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
  mv %{name}-%{TO_ARCH}-doc-$SE $DDC/%{name}-%{TO_ARCH}-doc-$DEC
%endif #BUILD_LOCAL_CROSS
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%files
%{_includedir}
%{_libdir}/pkgconfig
%{_libdir}/util-macros
%{_libdir}/xcb
/usr/share/aclocal

%files xcb-python
%{_prefix}/lib/python*

%files doc
%{_defaultdocdir}/*/*.html
%{_defaultdocdir}/*/*.svg
%{_defaultdocdir}/*/*.txt

%files doc-devel
%{_defaultdocdir}/*/*.db
%{_defaultdocdir}/*/*.xml

# ------------------- Cross Files ------------------------------------
%if %{BUILD_LOCAL_CROSS}

%Files %{TO_ARCH}
%{cross_includedir}
%{cross_libdir}/aclocal
%{cross_libdir}/pkgconfig
%{cross_libdir}/util-macros
%{cross_libdir}/xcb
%{cross_prefix}/lib/python*

%files %{TO_ARCH}-doc
%{cross_defaultdocdir}

%endif #!BUILD_LOCAL_CROSS
